==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/ClusterVersionStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterVersionStatusBuilder extends io.fabric8.openshift.api.model.ClusterVersionStatusFluentImpl<io.fabric8.openshift.api.model.ClusterVersionStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterVersionStatus,io.fabric8.openshift.api.model.ClusterVersionStatusBuilder>{
  public ClusterVersionStatusBuilder() {
    this(false);
  }
  public ClusterVersionStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterVersionStatus(), validationEnabled);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterVersionStatus(), validationEnabled);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableUpdates(instance.getAvailableUpdates()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withDesired(instance.getDesired()); 
    fluent.withHistory(instance.getHistory()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withVersionHash(instance.getVersionHash()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatus instance) {
    this(instance,false);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableUpdates(instance.getAvailableUpdates()); 
    this.withConditions(instance.getConditions()); 
    this.withDesired(instance.getDesired()); 
    this.withHistory(instance.getHistory()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withVersionHash(instance.getVersionHash()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterVersionStatus build() {
    ClusterVersionStatus buildable = new ClusterVersionStatus(fluent.getAvailableUpdates(),fluent.getConditions(),fluent.getDesired(),fluent.getHistory(),fluent.getObservedGeneration(),fluent.getVersionHash());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterVersionStatusBuilder that = (ClusterVersionStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ClusterVersionStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterVersionStatusBuilder extends io.fabric8.openshift.api.model.ClusterVersionStatusFluentImpl<io.fabric8.openshift.api.model.ClusterVersionStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterVersionStatus,io.fabric8.openshift.api.model.ClusterVersionStatusBuilder>{
  public ClusterVersionStatusBuilder() {
    this(false);
  }
  public ClusterVersionStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterVersionStatus(), validationEnabled);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterVersionStatus(), validationEnabled);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableUpdates(instance.getAvailableUpdates()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withDesired(instance.getDesired()); 
    fluent.withHistory(instance.getHistory()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withVersionHash(instance.getVersionHash()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatus instance) {
    this(instance,false);
  }
  public ClusterVersionStatusBuilder(io.fabric8.openshift.api.model.ClusterVersionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableUpdates(instance.getAvailableUpdates()); 
    this.withConditions(instance.getConditions()); 
    this.withDesired(instance.getDesired()); 
    this.withHistory(instance.getHistory()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withVersionHash(instance.getVersionHash()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterVersionStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterVersionStatus build() {
    ClusterVersionStatus buildable = new ClusterVersionStatus(fluent.getAvailableUpdates(),fluent.getConditions(),fluent.getDesired(),fluent.getHistory(),fluent.getObservedGeneration(),fluent.getVersionHash());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterVersionStatusBuilder that = (ClusterVersionStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
